User's Guide
============

Before you start diving into the details of programming systems and blocks, have
a look at the :doc:`mathematical background of dynamical systems <math>`, if you
haven't already. That theory will help you understand much better what goes on
in the system simulation.

Also, as MoDyPy is heavily based on `NumPy <https://numpy.org>`_, you might want
check out their documentation as well, at least the basic introduction into
`N-dimensional arrays
<https://numpy.org/doc/stable/reference/arrays.ndarray.html>`_.
However, you can also pick up a lot of that along the way.

Now, let us dive into creating system models.

.. toctree::
    :glob:
    :maxdepth: 1

    guide/*
